sqlalchemy\_authorize.oso package
=================================

Submodules
----------

sqlalchemy\_authorize.oso.oso\_permissions\_mixin module
--------------------------------------------------------

.. automodule:: sqlalchemy_authorize.oso.oso_permissions_mixin
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: sqlalchemy_authorize.oso
    :members:
    :undoc-members:
    :show-inheritance:
